#!/usr/bin/env python
#
# This file is part of MathTown
# Author(s): Brittany Morgan and Valerie Carrizales, Girlstart
# Copyright 2008
#
# Source code is derived from Girlstart's Project IT Girl Game Templates:
# http://itgirl.dreamhosters.com/itgirlgames/, http://www.girlstart.org/itgirl
# See the credits file for image sources.
#
# MathTown is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# MathTown is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with MathTown.  If not, see <http://www.gnu.org/licenses/>.

import pygame, ActivityBase
from helpers import *

class Activity1(ActivityBase.ActivityBase):
	def __init__(self,topleft,background_image,main_image_file,completed_image_file):
		ActivityBase.ActivityBase.__init__(self,topleft,background_image,main_image_file,completed_image_file)

	def askQuestion(self, questionText, answer1, answer1rect, answer2, answer2rect, answer3, answer3rect, correctAnswerrect):
		# questionText is the string of the question
		# answer1, answer2 and answer3 are the possible answers for the user to choose
		# answer1rect, answer2rect and answer3rect are the Rects that describe where the images for
		# the answers need to be drawn.
		# correctAnswer is the correct answer
		
		# Set up the font for our question.  Redraw the background first to clear the screen
		self.screen.blit(self.background, (0, 0))
		font = pygame.font.Font(None, 30)
		text = font.render(questionText, 1, (255, 255, 255))
		textrect = text.get_rect()
		textrect.centerx, textrect.centery = self.area.centerx,75
		self.screen.blit(text, textrect)
		
		# Draw our answers to the screen
		self.screen.blit(answer1, answer1rect)
		self.screen.blit(answer2, answer2rect)
		self.screen.blit(answer3, answer3rect)
		
		pygame.display.flip()
		
		# Now let's loop waiting for the user's answer
		answered = False
		while not answered:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.MOUSEBUTTONDOWN:
						if answer1rect.collidepoint(event.pos):
							# If we're here, then the user has clicked on one of the answers.
							answered = True
							if answer1rect == correctAnswerrect:
								# User answered correctly, let them know
								correct = True
							else:
								correct = False
						elif answer2rect.collidepoint(event.pos):
							answered = True
							if answer2rect == correctAnswerrect:
								correct = True
							else:
								correct = False
						elif answer3rect.collidepoint(event.pos):
							answered = True
							if answer3rect == correctAnswerrect:
								correct = True
							else:
								correct = False

		# The user has answered.  Display the results of their answer.  Remember, we need to redraw the background
		# in order to get rid of the previous stuff drawn to the screen.
		if correct:
			text = font.render("Correct!  Press any key to continue", 1, (255,255,255))
		else:
			text = font.render("Sorry, that's not correct.  Press any key to continue", 1, (255,255,255))
		
		self.screen.blit(self.background, (0, 0))
		textrect = text.get_rect()
		textrect.centerx, textrect.centery = self.area.centerx,75
		self.screen.blit(text, textrect)
		
		pygame.display.flip()
		
		# Now, wait for the user to click a key to continue:
		answered = False
		while not answered:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					answered = True				
		
		return correct


	def play(self):
		# Load all of our images for our question:
		answer1, answer1rect = load_image("2app8plm1.png")
		answer2, answer2rect = load_image("3app9plm.png")
		answer3, answer3rect = load_image("4app10plm.png")
		answer1rect.center = 150,400
		answer2rect.center = 450,400
		answer3rect.center = 750,400

		while not self.activity_completed:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
			# Ask our question until they get it right
			if self.askQuestion("Click on the picture with 3 apples and 9 plums.", answer1, answer1rect, answer2, answer2rect, answer3, answer3rect, answer2rect):self.activity_completed = True
		
			

		self.image = self.completed_image
		self.completed_image_rect.topleft = self.rect.topleft
		self.rect = self.completed_image_rect



class Activity2(ActivityBase.ActivityBase):
	def __init__(self,topleft,background_image,main_image_file,completed_image_file):
		ActivityBase.ActivityBase.__init__(self,topleft,background_image,main_image_file,completed_image_file)

	def play(self): 
		# load image for new background 
		self.background, self.background_rect = load_image("housebackground.bmp") 
		question = "What does 4+3=?" 
		answer_choices = ["7","6","8","9"] 
		correct_answer = "a" 
		answer_is_correct = False
		
		question2 = "What does 6+3=?"
		answer_choices2 = ["7","3","9","12"]
		correct_answer2= "c"
		answer2_is_correct = False
	
		question3= "What does 6+7=?"
		answer_choices3 = ["1","3","5","13"]
		correct_answer3 = "d"
		answer3_is_correct = False
		
		font = pygame.font.Font(None, 30) 
		

		
		if self.ask_multiple_choice_question(question,answer_choices,correct_answer):
			text = font.render("You answered correctly! Press any key to continue.", 1, (0,0,0))
			answer_is_correct = True
		else:
			text = font.render("Sorry, that's not correct. Press any key to continue.", 1, (0,0,0)) 
		self.screen.blit(self.background, (0,0)) 
		textrect = text.get_rect() 
		textrect.center = (400, 250) 
		self.screen.blit(text, textrect) 
		pygame.display.flip()	
		answered = False
		while not answered:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					answered = True			
					
		
		if self.ask_multiple_choice_question(question2,answer_choices2,correct_answer2):
			text = font.render("You answered correctly! Press any key to continue.", 1, (0,0,0))
			answer2_is_correct = True
		else:
			text = font.render("Sorry, that's not correct. Press any key to continue.", 1, (0,0,0)) 
		self.screen.blit(self.background, (0,0)) 
		textrect = text.get_rect() 
		textrect.center = (400, 250) 
		self.screen.blit(text, textrect) 
		pygame.display.flip()	
		answered2 = False
		while not answered2:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					answered2 = True	
					
		
					
		if self.ask_multiple_choice_question(question3,answer_choices3,correct_answer3):
			text = font.render("You answered correctly! Press any key to continue.", 1, (0,0,0))
			answer3_is_correct = True
		else:
			text = font.render("Sorry, that's not correct. Press any key to continue.", 1, (0,0,0)) 
		self.screen.blit(self.background, (0,0)) 
		textrect = text.get_rect() 
		textrect.center = (400, 250) 
		self.screen.blit(text, textrect) 
		pygame.display.flip()	
#		answered3 = False
#		while not answered3:
#			for event in pygame.event.get():
#				if event.type == pygame.QUIT:
#					sys.exit()
#				elif event.type == pygame.KEYDOWN:
#					answered3 = True				
					

		if (answer_is_correct) and (answer2_is_correct) and (answer3_is_correct):
			self.activity_completed = True;
				

		self.screen.blit(self.background, (0,0)) 
		textrect = text.get_rect() 
		textrect.center = (400, 250) 
		self.screen.blit(text, textrect) 
		pygame.display.flip()
		start_game = False 
		while not start_game: 
			for event in pygame.event.get(): 
				if event.type == pygame.QUIT: 
					sys.exit() # if the user closed the window, quit the game 
				elif event.type == pygame.KEYDOWN: # if the user pressed a key 
					start_game = True # start the game 
		

		while not self.activity_completed:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
			# Ask our question until they get it right
			if self.ask_multiple_choice_question(question,answer_choices,correct_answer) and self.ask_multiple_choice_question(question2,answer_choices2,correct_answer2)and self.ask_multiple_choice_question(question3,answer_choices3,correct_answer3):
				self.activity_completed = True
		
			

		self.image = self.completed_image
		self.completed_image_rect.topleft = self.rect.topleft
		self.rect = self.completed_image_rect

class Activity3(ActivityBase.ActivityBase):
	def __init__(self,topleft,background_image,main_image_file,completed_image_file):
		ActivityBase.ActivityBase.__init__(self,topleft,background_image,main_image_file,completed_image_file)

	def askQuestion(self, questionText, answer1, answer1rect, answer2, answer2rect, answer3, answer3rect, correctAnswerrect):
		# questionText is the string of the question
		# answer1, answer2 and answer3 are the possible answers for the user to choose
		# answer1rect, answer2rect and answer3rect are the Rects that describe where the images for
		# the answers need to be drawn.
		# correctAnswer is the correct answer
		
		# Set up the font for our question.  Redraw the background first to clear the screen
		self.screen.blit(self.background, (0, 0))
		font = pygame.font.Font(None, 30)
		text = font.render(questionText, 1, (255, 255, 255))
		textrect = text.get_rect()
		textrect.centerx, textrect.centery = self.area.centerx,75
		self.screen.blit(text, textrect)
		
		# Draw our answers to the screen
		self.screen.blit(answer1, answer1rect)
		self.screen.blit(answer2, answer2rect)
		self.screen.blit(answer3, answer3rect)
		
		pygame.display.flip()
		
		# Now let's loop waiting for the user's answer
		answered = False
		while not answered:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.MOUSEBUTTONDOWN:
						if answer1rect.collidepoint(event.pos):
							# If we're here, then the user has clicked on one of the answers.
							answered = True
							if answer1rect == correctAnswerrect:
								# User answered correctly, let them know
								correct = True
							else:
								correct = False
						elif answer2rect.collidepoint(event.pos):
							answered = True
							if answer2rect == correctAnswerrect:
								correct = True
							else:
								correct = False
						elif answer3rect.collidepoint(event.pos):
							answered = True
							if answer3rect == correctAnswerrect:
								correct = True
							else:
								correct = False

		# The user has answered.  Display the results of their answer.  Remember, we need to redraw the background
		# in order to get rid of the previous stuff drawn to the screen.
		if correct:
			text = font.render("Correct!  Press any key to continue", 1, (255,255,255))
		else:
			text = font.render("Sorry, that's not correct.  Press any key to continue", 1, (255,255,255))
		
		self.screen.blit(self.background, (0, 0))
		textrect = text.get_rect()
		textrect.centerx, textrect.centery = self.area.centerx,75
		self.screen.blit(text, textrect)
		
		pygame.display.flip()
		
		# Now, wait for the user to click a key to continue:
		answered = False
		while not answered:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					answered = True				
		
		return correct


	def play(self):
		# Load all of our images for our question:
		answer1, answer1rect = load_image("2lem4strw.bmp")
		answer2, answer2rect = load_image("3lem1strw.bmp")
		answer3, answer3rect = load_image("4lem3strw.bmp")
		answer1rect.center = 150,400
		answer2rect.center = 450,400
		answer3rect.center = 750,400

		while not self.activity_completed:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
			# Ask our question until they get it right
			if self.askQuestion("Click on the image with 4 lemons and 2 strawberries.", answer1, answer1rect, answer2, answer2rect, answer3, answer3rect, answer3rect):self.activity_completed = True
		
			

		self.image = self.completed_image
		self.completed_image_rect.topleft = self.rect.topleft
		self.rect = self.completed_image_rect


class Activity4(ActivityBase.ActivityBase):
	def __init__(self,topleft,background_image,main_image_file,completed_image_file):
		ActivityBase.ActivityBase.__init__(self,topleft,background_image,main_image_file,completed_image_file)
	
	def play(self):
		# load image for new background 
		self.background, self.background_rect = load_image("housebackground.bmp") 
		question = "What does 11+5=?" 
		answer_choices = ["6","16","18","9"] 
		correct_answer = "b" 
		answer_is_correct = False
		
		question2 = "What does 8+9=?"
		answer_choices2 = ["17","1","19","12"]
		correct_answer2= "a"
		answer2_is_correct = False
	
		question3= "What does 13+7=?"
		answer_choices3 = ["6","23","21","20"]
		correct_answer3 = "d"
		answer3_is_correct = False
		
		font = pygame.font.Font(None, 30) 
		

		
		if self.ask_multiple_choice_question(question,answer_choices,correct_answer):
			text = font.render("You answered correctly! Press any key to continue.", 1, (0,0,0))
			answer_is_correct = True
		else:
			text = font.render("Sorry, that's not correct. Press any key to continue.", 1, (0,0,0)) 
		self.screen.blit(self.background, (0,0)) 
		textrect = text.get_rect() 
		textrect.center = (400, 250) 
		self.screen.blit(text, textrect) 
		pygame.display.flip()	
		answered = False
		while not answered:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					answered = True			
					
		
		if self.ask_multiple_choice_question(question2,answer_choices2,correct_answer2):
			text = font.render("You answered correctly! Press any key to continue.", 1, (0,0,0))
			answer2_is_correct = True
		else:
			text = font.render("Sorry, that's not correct. Press any key to continue.", 1, (0,0,0)) 
		self.screen.blit(self.background, (0,0)) 
		textrect = text.get_rect() 
		textrect.center = (400, 250) 
		self.screen.blit(text, textrect) 
		pygame.display.flip()	
		answered2 = False
		while not answered2:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					answered2 = True	
					
		
					
		if self.ask_multiple_choice_question(question3,answer_choices3,correct_answer3):
			text = font.render("You answered correctly! Press any key to continue.", 1, (0,0,0))
			answer3_is_correct = True
		else:
			text = font.render("Sorry, that's not correct. Press any key to continue.", 1, (0,0,0)) 
		self.screen.blit(self.background, (0,0)) 
		textrect = text.get_rect() 
		textrect.center = (400, 250) 
		self.screen.blit(text, textrect) 
		pygame.display.flip()	
#		answered3 = False
#		while not answered3:
#			for event in pygame.event.get():
#				if event.type == pygame.QUIT:
#					sys.exit()
#				elif event.type == pygame.KEYDOWN:
#					answered3 = True				
					

		if (answer_is_correct) and (answer2_is_correct) and (answer3_is_correct):
			self.activity_completed = True;
				

		self.screen.blit(self.background, (0,0)) 
		textrect = text.get_rect() 
		textrect.center = (400, 250) 
		self.screen.blit(text, textrect) 
		pygame.display.flip()
		start_game = False 
		while not start_game: 
			for event in pygame.event.get(): 
				if event.type == pygame.QUIT: 
					sys.exit() # if the user closed the window, quit the game 
				elif event.type == pygame.KEYDOWN: # if the user pressed a key 
					start_game = True # start the game 
		

		while not self.activity_completed:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
			# Ask our question until they get it right
			if self.ask_multiple_choice_question(question,answer_choices,correct_answer) and self.ask_multiple_choice_question(question2,answer_choices2,correct_answer2)and self.ask_multiple_choice_question(question3,answer_choices3,correct_answer3):
				self.activity_completed = True
		
			

		self.image = self.completed_image
		self.completed_image_rect.topleft = self.rect.topleft
		self.rect = self.completed_image_rect
#	def play(self): 
#		# load image for new background 
#		self.background, self.background_rect = load_image("housebackground.bmp") 
#		question = "What does 4+5=?" 
#		answer_choices = ["2","9","12","13"] 
#		correct_answer = "b" 
#		font = pygame.font.Font(None, 30) 
#		if self.ask_multiple_choice_question(question,answer_choices,correct_answer): 
#			text = font.render("You answered correctly! Press any key to continue.", 1, (0,0,0))
#			self.activity_completed = True
#		else:
#			text = font.render("Sorry, that's not correct. Press any key to continue.", 1, (0,0,0)) 
#		self.screen.blit(self.background, (0,0)) 
#		textrect = text.get_rect() 
#		textrect.center = (400, 250) 
#		self.screen.blit(text, textrect) 
#		pygame.display.flip() 
#		start_game = False 
#		while not start_game: 
#			for event in pygame.event.get(): 
#				if event.type == pygame.QUIT: 
#					sys.exit() # if the user closed the window, quit the game 
#				elif event.type == pygame.KEYDOWN: # if the user pressed a key 
#					start_game = True # start the game 
#		
#
#		while not self.activity_completed:
#			for event in pygame.event.get():
#				if event.type == pygame.QUIT:
#					sys.exit()
#			# Ask our question until they get it right
#			if self.ask_multiple_choice_question(question,answer_choices,correct_answer):self.activity_completed = True
#		
#			
#
#		self.image = self.completed_image
#		self.completed_image_rect.topleft = self.rect.topleft
#		self.rect = self.completed_image_rect
